@@ -10,30 +10,27 @@ import style from './style.css'
 import sharedStyle from '../sharedStyle.css'
 
 import {
-  downloadConsole,
   getConsoleOptions,
   saveConsoleOptions,
-  getRDP,
-  changeVmIcon,
-  changeVmIconById,
-} from '../../actions/index'
+} from '../../actions'
 
-import { templateNameRenderer } from '../../helpers'
+import { templateNameRenderer, userFormatOfBytes } from '../../helpers'
 
-import FieldHelp from '../FieldHelp/index'
+import ConsoleOptions from '../ConsoleOptions'
 import DetailContainer from '../DetailContainer'
-import ConsoleOptions from '../ConsoleOptions/index'
-import VmDisks from '../VmDisks/index'
-import VmNics from '../VmNics/index'
-import VmsListNavigation from '../VmsListNavigation/index'
-import VmStatus from './VmStatus'
-import { NextRunLabel } from './labels'
+import FieldHelp from '../FieldHelp'
 import LastMessage from './LastMessage'
 import VmConsoles from './VmConsoles'
+import VmDisks from '../VmDisks'
+import VmIcon from '../VmIcon'
+import VmNics from '../VmNics'
+import VmsListNavigation from '../VmsListNavigation'
+import VmSnapshots from '../VmSnapshots'
+import VmStatus from './VmStatus'
+import { NextRunLabel } from './labels'
 
-import { userFormatOfBytes, VmIcon } from 'ovirt-ui-components'
 import Selectors from '../../selectors'
-import { getOsHumanName } from '../utils'
+import { getOsHumanName, getVmIcon } from '../utils'
 
 function rephraseVmType (vmType) {
   const types = {
@@ -47,7 +44,7 @@ function rephraseVmType (vmType) {
     return types[type]
   }
 
-  console.info('rephraseVmType(): vmType not explicitely defined: ', vmType)
+  console.info('rephraseVmType(): vmType not explicitly defined: ', vmType)
   return vmType
 }
 
@@ -58,14 +55,10 @@ class VmDetail extends Component {
       openConsoleSettings: false,
       vmsNavigationExpanded: true,
       editDisks: false,
-      openNicSettings: false,
     }
 
     this.consoleSettings = this.consoleSettings.bind(this)
-    this.nicSettings = this.nicSettings.bind(this)
     this.toggleVmsNavExpansion = this.toggleVmsNavExpansion.bind(this)
-    this.handleIconChange = this.handleIconChange.bind(this)
-    this.handleIconChangeToDefault = this.handleIconChangeToDefault.bind(this)
     this.editDisks = this.editDisks.bind(this)
   }
 
@@ -99,73 +92,41 @@ class VmDetail extends Component {
     e.preventDefault()
   }
 
-  handleIconChange (e) {
-    const that = this
-    const reader = new FileReader()
-    const file = e.target.files[0]
-
-    reader.onload = function (upload) {
-      let iconBase64 = upload.target.result
-      iconBase64 = iconBase64.replace('data:', '')
-      const semiIndex = iconBase64.indexOf(';')
-      const mimeType = iconBase64.slice(0, semiIndex)
-      iconBase64 = iconBase64.slice(semiIndex + 1).replace('base64,', '')
-
-      that.props.onIconChange({ iconBase64, mimeType })
-    }
-    reader.readAsDataURL(file)
-  }
-
-  handleIconChangeToDefault () {
-    const vmOs = this.props.operatingSystems.get('operatingSystems').find((v, k) => v.get('name') === this.props.vm.getIn(['os', 'type']))
-    if (vmOs) {
-      const iconId = vmOs.getIn(['icons', 'large', 'id'])
-      this.props.onIconChangeToDefault({ iconId })
-    }
-  }
-
   render () {
     const {
       vm,
-      icons,
-      userMessages,
-      onConsole,
-      isPool,
-      onConsoleOptionsSave,
-      options,
       pool,
-      onRDP,
+      icons,
+      options,
+      userMessages,
       operatingSystems,
-      config,
+      onConsoleOptionsSave,
     } = this.props
 
+    const sequence = [ 'first', 'second' ]
+
+    const isPool = !!pool
+    const isPoolVm = !!vm.getIn(['pool', 'id'])
     const name = isPool ? pool.get('name') : vm.get('name')
     const idPrefix = `vmdetail-${name}`
-    let iconId = vm.getIn(['icons', 'large', 'id'])
-    const vmsIcons = operatingSystems.get('operatingSystems').find((v, k) => v.getIn(['icons', 'large', 'id']) === iconId)
-    if (vmsIcons) {
-      const vmOs = operatingSystems.get('operatingSystems').find((v, k) => v.get('name') === vm.getIn(['os', 'type']))
-      if (vmOs) {
-        iconId = vmOs.getIn(['icons', 'large', 'id'])
-      }
-    }
-    const icon = icons.get(iconId)
+    const icon = getVmIcon(icons, operatingSystems, vm)
     const disks = vm.get('disks')
     const nics = vm.get('nics')
+    const snapshots = vm.get('snapshots')
     const osName = getOsHumanName(vm.getIn(['os', 'type']))
     const cluster = Selectors.getClusterById(vm.getIn(['cluster', 'id']))
     const template = Selectors.getTemplateById(vm.getIn(['template', 'id']))
 
     const disksElement = (<VmDisks disks={disks} vmId={vm.get('id')} edit={this.state.editDisks} />)
 
-    const diskEditAllowed = !isPool && !vm.getIn(['pool', 'id'])
+    const diskEditAllowed = !isPool && !isPoolVm
     const pencilIcon = (<i className={`pficon pficon-edit`} />)
     const disksEditPencil = (
       <small className={style.editPencilLink}>
         {
           diskEditAllowed
-          ? (<a href='#' onClick={this.editDisks} id={`${idPrefix}-edit-disks`}>{pencilIcon}</a>)
-          : (<FieldHelp content={msg.notEditableForPoolsOrPoolVms()} text={pencilIcon} />)
+            ? (<a href='#' onClick={this.editDisks} id={`${idPrefix}-edit-disks`}>{pencilIcon}</a>)
+            : (<FieldHelp content={msg.notEditableForPoolsOrPoolVms()} text={pencilIcon} />)
         }
       </small>)
 
@@ -179,24 +140,10 @@ class VmDetail extends Component {
       </small>)
 
     const notPoolOrPoolVm = !isPool && vm.getIn(['pool', 'id']) === undefined
-    const nicOptionsShowHide = notPoolOrPoolVm ? (
-      <small>
-        <a href='#' onClick={this.nicSettings} id={`${idPrefix}-nicoptions-showhide`}>
-          {pencilIcon}
-        </a>
-      </small>
-    ) : (
-      <small>
-        <FieldHelp content={msg.notEditableForPoolsOrPoolVms()} text={pencilIcon} />
-      </small>
-    )
 
     const hasDisks = disks.size > 0
     const noDisks = hasDisks || (<small>{msg.noDisks()} &nbsp;</small>)
 
-    const hasNics = nics.size > 0
-    const noNics = hasNics || (<dd><small>{msg.noNics()}</small></dd>)
-
     const consolesHelp = (
       <div>
         <p id={`${idPrefix}-consolehelp-one`}>{msg.ifVmIsRunningClickToAccessItsGraphicsConsole()}</p>
@@ -204,27 +151,16 @@ class VmDetail extends Component {
       </div>
     )
 
-    let vmIcon = (<VmIcon
-      icon={icon}
-      missingIconClassName='pficon pficon-virtual-machine'
-      className={sharedStyle['vm-detail-icon']}
-      onIconChange={this.handleIconChange}
-      onIconDefault={this.handleIconChangeToDefault}
-      showEdit
-      />)
+    let vmIcon = (<VmIcon icon={icon} missingIconClassName='pficon pficon-virtual-machine' />)
 
     if (isPool) {
-      vmIcon = <VmIcon
-        icon={icon}
-        missingIconClassName='pficon pficon-virtual-machine'
-        className={sharedStyle['vm-detail-icon']}
-        />
+      vmIcon = <VmIcon icon={icon} missingIconClassName='pficon pficon-virtual-machine' />
     }
 
     return (
-      <div className={style['main-container']} data-thisisvmdetail>
+      <div className={`detail-container ${style['main-container']}`} data-thisisvmdetail>
         <VmsListNavigation selectedVm={vm} expanded={this.state.vmsNavigationExpanded} toggleExpansion={this.toggleVmsNavExpansion} />
-        <div className={style['vm-detail-main']}>
+        <div className={style['vm-detail-main']} container='true'>
           <div className={this.state.vmsNavigationExpanded ? style['vms-nav-expanded'] : style['vms-nav-collapsed']}>
             <DetailContainer>
               <h1 className={style['header']}>
@@ -291,10 +227,10 @@ class VmDetail extends Component {
                 <dl className={sharedStyle['vm-properties']}>
                   <dt><span className='pficon pficon-screen' />
                     &nbsp;
-                    <FieldHelp content={consolesHelp} text={msg.console()} popoverWidth='220px' />
+                    <FieldHelp content={consolesHelp} text={msg.console()} />
                     {consoleOptionsShowHide}
                   </dt>
-                  <VmConsoles vm={vm} onConsole={onConsole} onRDP={onRDP} usbFilter={config.get('usbFilter')} />
+                  <VmConsoles vm={vm} />
                   <ConsoleOptions smartcardOptionEnable={vm.getIn(['display', 'smartcardEnabled'])} options={optionsJS} onSave={onConsoleOptionsSave} open={this.state.openConsoleSettings} />
 
                   <dt>
@@ -305,18 +241,26 @@ class VmDetail extends Component {
                   </dt>
                   {noDisks}
                   {disksElement}
-                  <dt><span className='pficon pficon-container-node' />
-                    &nbsp;
-                    <FieldHelp content={msg.nicsTooltip()} text={msg.nic()} />
-                    &nbsp;
-                    {nicOptionsShowHide}
-                  </dt>
-                  {noNics}
-                  <VmNics nics={nics} vmId={vm.get('id')} showSettings={this.state.openNicSettings && notPoolOrPoolVm} />
+                  <VmNics nics={nics} vmId={vm.get('id')} enableSettings={notPoolOrPoolVm} />
+                  <VmSnapshots snapshots={snapshots} vm={vm} enableSettings={notPoolOrPoolVm} />
                   <dt>
                     <FieldHelp content={msg.bootMenuTooltip()} text={msg.bootMenu()} />
                   </dt>
                   <dd>{vm.get('bootMenuEnabled') ? msg.on() : msg.off()}</dd>
+                  <dt>
+                    <FieldHelp content={msg.bootSequenceTooltip()} text={msg.bootSequence()} />
+                  </dt>
+                  <dd />
+                  {vm.getIn(['os', 'bootDevices']).map((device, key) =>
+                    <React.Fragment key={key}>
+                      <dt className={style['field-shifted']}>
+                        <FieldHelp content={msg[`${sequence[key]}DeviceTooltip`]()} text={msg[`${sequence[key]}Device`]()} />
+                      </dt>
+                      <dd>
+                        {msg[`${device}Boot`]()}
+                      </dd>
+                    </React.Fragment>
+                  )}
                   <dt>
                     <FieldHelp content={msg.cloudInitTooltip()} text={msg.cloudInit()} />
                   </dt>
@@ -333,34 +277,26 @@ class VmDetail extends Component {
 VmDetail.propTypes = {
   vm: PropTypes.object,
   pool: PropTypes.object,
+
   icons: PropTypes.object.isRequired,
-  operatingSystems: PropTypes.object.isRequired,
+  options: PropTypes.object.isRequired,
+  operatingSystems: PropTypes.object.isRequired, // deep immutable, {[id: string]: OperatingSystem}
   userMessages: PropTypes.object.isRequired,
-  onConsole: PropTypes.func.isRequired,
+
   onConsoleOptionsSave: PropTypes.func.isRequired,
   onConsoleOptionsOpen: PropTypes.func.isRequired,
-  options: PropTypes.object.isRequired,
-  isPool: PropTypes.bool,
-  config: PropTypes.object.isRequired,
-  onRDP: PropTypes.func.isRequired,
-  onIconChange: PropTypes.func.isRequired,
-  onIconChangeToDefault: PropTypes.func.isRequired,
 }
 
 export default connect(
   (state) => ({
     icons: state.icons,
-    userMessages: state.userMessages,
     options: state.options,
     operatingSystems: state.operatingSystems,
+    userMessages: state.userMessages,
   }),
 
-  (dispatch, { vm, config }) => ({
-    onConsole: ({ vmId, consoleId }) => dispatch(downloadConsole({ vmId, consoleId, usbFilter: config.get('usbFilter') })),
+  (dispatch, { vm }) => ({
     onConsoleOptionsSave: ({ options }) => dispatch(saveConsoleOptions({ vmId: vm.get('id'), options })),
     onConsoleOptionsOpen: () => dispatch(getConsoleOptions({ vmId: vm.get('id') })),
-    onRDP: () => dispatch(getRDP({ vmName: vm.get('name'), username: config.getIn([ 'user', 'name' ]), domain: config.get('domain'), fqdn: vm.get('fqdn') })),
-    onIconChange: ({ iconBase64, mimeType }) => dispatch(changeVmIcon({ vmId: vm.get('id'), iconBase64, mimeType })),
-    onIconChangeToDefault: ({ iconId }) => dispatch(changeVmIconById({ vmId: vm.get('id'), iconId })),
   })
 )(VmDetail)
