@@ -1,9 +1,6 @@
 
 import { locale as appLocale } from '../../intl'
-
-function localeCompare (a, b, locale = appLocale) {
-  return a.localeCompare(b, locale, { numeric: true })
-}
+import { localeCompare } from '../../helpers'
 
 /*
  * Sort an Immutable List of Maps (set of disks) for display on the VmDisks list.
@@ -14,8 +11,8 @@ export function sortDisksForDisplay (disks, locale = appLocale) {
     const aBoot = a.get('bootable')
     const bBoot = b.get('bootable')
 
-    return aBoot && !bBoot ? -1
-      : !aBoot && bBoot ? 1
-      : localeCompare(a.get('name'), b.get('name'), locale)
+    return (aBoot && !bBoot) ? -1 : (
+      (!aBoot && bBoot) ? 1 : localeCompare(a.get('name'), b.get('name'), locale)
+    )
   })
 }
