@@ -1,4 +1,4 @@
-import React, { Component } from 'react'
+import React from 'react'
 import PropTypes from 'prop-types'
 import { connect } from 'react-redux'
 import { addVmNic, deleteVmNic } from '../../actions'
@@ -6,7 +6,8 @@ import { Button } from 'patternfly-react'
 import DeleteConfirmationModal from '../VmModals/DeleteConfirmationModal'
 import { msg } from '../../intl'
 import FieldHelp from '../FieldHelp'
-import naturalCompare from 'string-natural-compare'
+import VmDetailRow, { ExpandableList } from '../VmDetailRow'
+import { localeCompare } from '../../helpers'
 
 import NewNicModal from './NewNicModal'
 import style from './style.css'
@@ -34,7 +35,7 @@ class VmNic extends React.Component {
   }
 
   render () {
-    let { nic, vnicProfile, showSettings } = this.props
+    let { nic, vnicProfile, showSettings, isUp } = this.props
     const idPrefix = `vmnic-${nic.get('name')}`
     const nicInfoContent = (
       <div id={`${idPrefix}-nic-info`}>
@@ -63,10 +64,10 @@ class VmNic extends React.Component {
           </span>
           {
             showSettings
-            ? (<Button bsStyle='default' bsSize='small' onClick={this.handleOpenDialog}>
-              {msg.delete()}
-            </Button>)
-            : null
+              ? (<Button bsStyle='default' bsSize='small' onClick={this.handleOpenDialog} disabled={isUp}>
+                {msg.delete()}
+              </Button>)
+              : null
           }
           <DeleteConfirmationModal show={this.state.showDeleteModal} onDelete={this.handleDelete} onClose={this.handleClose}>
             <p dangerouslySetInnerHTML={{ __html: msg.areYouSureYouWantToDeleteNic({ nicName: `"<strong>${this.props.nic.get('name')}</strong>"` }) }} />
@@ -81,83 +82,46 @@ VmNic.propTypes = {
   nic: PropTypes.object.isRequired,
   vnicProfile: PropTypes.object,
   showSettings: PropTypes.bool,
+  isUp: PropTypes.bool,
   onDelete: PropTypes.func.isRequired,
 }
 
-class VmNics extends Component {
-  constructor (props) {
-    super(props)
-    this.state = {
-      renderMore: false,
+const VmNics = function ({ nics, vnicProfiles, onNicAdd, enableSettings, onNicDelete }) {
+  let nextNicId = 0
+  nics.forEach((value) => {
+    const valueNum = value.get('name').match(/nic(\d+)/)
+    const parsedIndex = valueNum !== null && parseInt(valueNum[1])
+    if (parsedIndex && nextNicId <= parsedIndex) {
+      nextNicId = parsedIndex + 1
     }
-  }
+  })
+  const nextNicName = nextNicId !== 0 ? `nic${nextNicId}` : 'nic1'
 
-  render () {
-    const { nics, vnicProfiles, onNicAdd, showSettings, onNicDelete } = this.props
+  let renderedNics = nics.sort((a, b) => localeCompare(a.get('name'), b.get('name'))).map(nic => {
+    const vnicProfile = vnicProfiles.get(nic.getIn(['vnicProfile', 'id']))
+    return (<VmNic nic={nic} vnicProfile={vnicProfile} key={nic.get('id')} onDelete={onNicDelete} />)
+  }).toJS()
 
-    const MAX_VISIBLE_NICS = 2
+  const idPrefix = `vmnics-`
 
-    let nextNicId = 0
-    nics.forEach((value) => {
-      const valueNum = value.get('name').match(/nic(\d+)/)
-      const parsedIndex = valueNum !== null && parseInt(valueNum[1])
-      if (parsedIndex && nextNicId <= parsedIndex) {
-        nextNicId = parsedIndex + 1
-      }
-    })
-    const nextNicName = nextNicId !== 0 ? `nic${nextNicId}` : 'nic1'
+  const nicsModal = <NewNicModal vnicProfiles={vnicProfiles} nextNicName={nextNicName} onAdd={onNicAdd} />
 
-    let classes = style['nics-list']
-
-    let nicsToRender = nics.sort((a, b) => naturalCompare.caseInsensitive(a.get('name'), b.get('name')))
-    if (!this.state.renderMore) {
-      nicsToRender = nicsToRender.slice(0, MAX_VISIBLE_NICS)
-    }
-
-    const idPrefix = `vmnics-`
-
-    const nicsModal = showSettings && <NewNicModal vnicProfiles={vnicProfiles} nextNicName={nextNicName} onAdd={onNicAdd} />
-
-    let moreButton = null
-    const hiddenCount = nics.size - MAX_VISIBLE_NICS
-    if (hiddenCount > 0) {
-      if (this.state.renderMore) {
-        moreButton = (
-          <div className={style['button-more']} onClick={() => this.setState({ renderMore: false })} id={`${idPrefix}-button-less`}>
-            {msg.less()}
-          </div>
-        )
-      } else {
-        moreButton = (
-          <div className={style['button-more']} onClick={() => this.setState({ renderMore: true })} id={`${idPrefix}-button-more`}>
-            {msg.more()} ({hiddenCount})
-          </div>
-        )
-      }
-    }
-
-    return (
-      <div className={classes}>
-        <ul className={style['nics-ul']}>
-          {
-            nicsToRender.map(nic => {
-              const vnicProfile = vnicProfiles.get(nic.getIn(['vnicProfile', 'id']))
-              return (<VmNic nic={nic} vnicProfile={vnicProfile} key={nic.get('id')} showSettings={showSettings} onDelete={onNicDelete} />)
-            })
-          }
-
-        </ul>
-        {moreButton}
-        {nicsModal}
-      </div>
-    )
-  }
+  return (
+    <VmDetailRow
+      label={msg.nic()}
+      labelTooltip={msg.nicsTooltip()}
+      iconClassname='pficon pficon-container-node'
+      editor={<ExpandableList items={renderedNics} noItemsTitle={msg.noNics()} addItemComponent={nicsModal} idPrefix={idPrefix} />}
+      enableSettings={enableSettings}
+    />
+  )
 }
+
 VmNics.propTypes = {
-  vmId: PropTypes.string.isRequired,
+  vm: PropTypes.object.isRequired, // eslint-disable-line react/no-unused-prop-types
   nics: PropTypes.object.isRequired,
   vnicProfiles: PropTypes.object.isRequired,
-  showSettings: PropTypes.bool,
+  enableSettings: PropTypes.bool,
   onNicAdd: PropTypes.func.isRequired,
   onNicDelete: PropTypes.func.isRequired,
 }
@@ -167,8 +131,8 @@ export default connect(
     vnicProfiles: state.vnicProfiles,
   }),
 
-  (dispatch, { vmId }) => ({
-    onNicAdd: ({ nic }) => dispatch(addVmNic({ vmId, nic })),
-    onNicDelete: ({ nicId }) => dispatch(deleteVmNic({ vmId, nicId })),
+  (dispatch, { vm }) => ({
+    onNicAdd: ({ nic }) => dispatch(addVmNic({ vmId: vm.get('id'), nic })),
+    onNicDelete: ({ nicId }) => dispatch(deleteVmNic({ vmId: vm.get('id'), nicId })),
   })
 )(VmNics)
