@@ -3,13 +3,11 @@ import PropTypes from 'prop-types'
 
 import { connect } from 'react-redux'
 
-import {
-  logout,
-  toggleOptions,
-  clearUserMessages,
-} from '../../actions/index'
+import { logout } from '../../actions/index'
 
 import { msg } from '../../intl'
+import AboutDialog from '../About'
+import OptionsDialog from '../OptionsDialog'
 
 const UserMenu = ({ config, onLogout }) => {
   if (!config.get('loginToken')) { // this shall really not happen!
@@ -20,7 +18,7 @@ const UserMenu = ({ config, onLogout }) => {
       </li>
     )
   } else {
-    const idPrefix = `usermenu`
+    const idPrefix = 'usermenu'
     return (
       <li className='dropdown'>
         <a className='dropdown-toggle nav-item-iconic' href='#' data-toggle='dropdown' title={config.getIn(['user', 'name'])} id={`${idPrefix}-user`}>
@@ -28,10 +26,10 @@ const UserMenu = ({ config, onLogout }) => {
         </a>
         <ul className='dropdown-menu'>
           <li>
-            <a href='#' data-toggle='modal' data-target='#options-modal' id={`${idPrefix}-options`}>{msg.options()}</a>
+            <OptionsDialog userId={config.getIn(['user', 'id'])} />
           </li>
           <li>
-            <a href='#' data-toggle='modal' data-target='#about-modal' id={`${idPrefix}-about`}>{msg.about()}</a>
+            <AboutDialog />
           </li>
           <li>
             <a href='#' onClick={onLogout} id={`${idPrefix}-logout`}>{msg.logOut()}</a>
@@ -45,7 +43,6 @@ const UserMenu = ({ config, onLogout }) => {
 UserMenu.propTypes = {
   config: PropTypes.object.isRequired,
   onLogout: PropTypes.func.isRequired,
-  onOptions: PropTypes.func.isRequired,
 }
 
 export default connect(
@@ -53,8 +50,6 @@ export default connect(
     config: state.config,
   }),
   (dispatch) => ({
-    onClearMessages: () => dispatch(clearUserMessages()),
     onLogout: () => dispatch(logout()),
-    onOptions: () => dispatch(toggleOptions()),
   })
 )(UserMenu)
