@@ -1,4 +1,5 @@
 import { Blob } from 'blob-util'
+import { locale as appLocale } from './intl'
 
 let logDebugEnabled = true
 
@@ -131,7 +132,7 @@ export function hrefWithoutHistory (handler) {
 
 export function getURLQueryParameterByName (name) {
   const url = window.location.href
-  name = name.replace(/[\[\]]/g, '\\$&')
+  name = name.replace(/[\[\]]/g, '\\$&') // eslint-disable-line no-useless-escape
   const regex = new RegExp('[?&]' + name + '(=([^&#]*)|&|#|$)')
   const results = regex.exec(url)
 
@@ -145,3 +146,82 @@ export function getURLQueryParameterByName (name) {
   const uriComponent = results[2].replace(/\+/g, ' ')
   return decodeURIComponent(uriComponent)
 }
+
+/**
+ * Return bytes in human readable format.
+ *
+ * [ human readable string, divised number, suffix ]
+ *
+ * @param number in Bytes
+ * @param suffix optional
+ * @returns {*}
+ */
+export function userFormatOfBytes (number, suffix) {
+  const buildRetVal = (number, suffix) => {
+    const rounded = number.toFixed(1)
+    return {
+      str: `${rounded} ${suffix}`,
+      rounded,
+      number,
+      suffix,
+    }
+  }
+  number = number || 0
+  const factor = 1024
+  const suffixes = [null, 'KiB', 'MiB', 'GiB', 'TiB', 'PiB', 'EiB', 'ZiB']
+
+  if (suffix) {
+    const i = suffixes.indexOf(suffix)
+    if (i > 0) {
+      const divisor = Math.pow(factor, i)
+      number = number / divisor
+
+      return buildRetVal(number, suffix)
+    }
+  }
+
+  // figure it out
+  let divisor = 1
+  suffix = ''
+  for (let i = 0; i < suffixes.length; i++) {
+    const quotient = number / divisor
+    if (quotient < factor) {
+      number = quotient
+      suffix = suffixes[i]
+      break
+    }
+    divisor *= factor
+  }
+
+  return buildRetVal(number, suffix)
+}
+
+export function localeCompare (a, b, locale = appLocale) {
+  return a.localeCompare(b, locale, { numeric: true })
+}
+
+export function sortedBy (array, sortBy, locale = appLocale) {
+  return array.sort((a, b) => localeCompare(a[sortBy], b[sortBy], locale))
+}
+
+/**
+ * Similar to lodash keyBy
+ * @param {Array<T>} array
+ * @param {(T) => K} keySelector
+ * @return {{[K]: T}} map
+ */
+export function arrayToMap (array, keySelector) {
+  return array.reduce((accum, item) => {
+    const key = keySelector(item)
+    accum[key] = item
+    return accum
+  }, {})
+}
+
+export function getFormatedDateTime (timestamp) {
+  const t = new Date(timestamp)
+  return {
+    time: `${formatTwoDigits(t.getHours())}:${formatTwoDigits(t.getMinutes())}:${formatTwoDigits(t.getSeconds())}`,
+    date: `${t.getDate()}/${t.getMonth()}/${t.getFullYear()}`,
+  }
+}
