@@ -1,4 +1,5 @@
 // @flow
+/* eslint-disable import/first */
 
 /**
   Flow agreement:
@@ -10,11 +11,31 @@ import ReactDOM from 'react-dom'
 import { Provider } from 'react-redux'
 import { IntlProvider } from 'react-intl'
 
-import './index-nomodules.css'
+// TODO: Look at this WRT patternfly-react CSS!!!!!!!
 import 'patternfly/dist/css/patternfly.css'
 import 'patternfly/dist/css/patternfly-additions.css'
+import './index-nomodules.css'
 import * as branding from './branding'
-import { getSelectedMessages, locale } from './intl/index'
+
+import { getSelectedMessages, locale } from './intl'
+import configureStore from './store'
+import Selectors from './selectors'
+import AppConfiguration, { readConfiguration } from './config'
+import { loadStateFromLocalStorage } from './storage'
+import { logDebug, logError, valuesOfObject } from './helpers'
+import { rootSaga } from './sagas'
+import {
+  login,
+  updateIcons,
+  setDomain,
+  addActiveRequest,
+  delayedRemoveActiveRequest,
+} from './actions'
+import OvirtApi from './ovirtapi'
+
+import App from './App'
+
+// eslint-disable "import/first": off
 
 // Patternfly dependencies
 // jQuery needs to be globally available (webpack.ProvidePlugin can be also used for this)
@@ -25,21 +46,11 @@ window.patternfly = require('patternfly/dist/js/patternfly')
 window.selectpicker = require('bootstrap-select/js/bootstrap-select.js')
 window.combobox = require('patternfly-bootstrap-combobox/js/bootstrap-combobox.js')
 
-import store, { sagaMiddleware } from './store'
-import Selectors from './selectors'
-import AppConfiguration, { readConfiguration } from './config'
-import { loadStateFromLocalStorage } from './storage'
-import { logDebug, logError, valuesOfObject } from './helpers'
-import { rootSaga } from './sagas'
-import { login, updateIcons, setDomain, schedulerOneMinute } from './actions'
-
-import App from './App'
-
-function renderApp () {
+function renderApp (store: Object) {
   ReactDOM.render(
     <Provider store={store}>
       <IntlProvider locale={locale} messages={getSelectedMessages()}>
-        <App />
+        <App history={store.history} />
       </IntlProvider>
     </Provider>,
     (document.getElementById('root'): any)
@@ -74,7 +85,7 @@ function fetchToken (): { token: string, username: string, domain: string, userI
   }
 }
 
-function loadPersistedState () {
+function loadPersistedState (store: Object) {
   // load persisted icons, etc ...
   const { icons } = loadStateFromLocalStorage()
 
@@ -98,10 +109,16 @@ function addLinkElement (rel: string, href: string) {
   window.document.head.appendChild(linkElement)
 }
 
-function start () {
-  readConfiguration()
-    .then(branding.loadOnce)
-    .then(onResourcesLoaded)
+function initializeApiListener (store: Object) {
+  OvirtApi.addHttpListener((requestId, eventType) => {
+    if (eventType === 'START') {
+      store.dispatch(addActiveRequest(requestId))
+      return
+    }
+    if (eventType === 'STOP') {
+      store.dispatch(delayedRemoveActiveRequest(requestId))
+    }
+  })
 }
 
 function onResourcesLoaded () {
@@ -109,27 +126,28 @@ function onResourcesLoaded () {
 
   addBrandedResources()
 
-  const { token, username, domain, userId }: { token: string, username: string, domain: string, userId: string } = fetchToken()
+  const store = configureStore()
+  store.runSaga(rootSaga)
+  Selectors.init({ store })
+  initializeApiListener(store)
+  loadPersistedState(store)
 
   // do initial render
-  renderApp()
-
-  // handle external actions
-  sagaMiddleware.run(rootSaga)
-
-  // initiate data retrieval
-  Selectors.init({ store })
-
-  loadPersistedState()
+  renderApp(store)
 
+  const { token, username, domain, userId }: { token: string, username: string, domain: string, userId: string } = fetchToken()
   store.dispatch(setDomain({ domain }))
   if (token) {
     store.dispatch(login({ username, token, userId }))
   } else {
     logError('Missing SSO Token!')
   }
+}
 
-  store.dispatch(schedulerOneMinute())
+function start () {
+  readConfiguration()
+    .then(branding.loadOnce)
+    .then(onResourcesLoaded)
 }
 
 start()
