@@ -1,16 +1,24 @@
 import Immutable from 'immutable'
+import {
+  CLEAR_USER_MSGS,
+  DISMISS_USER_MSG,
+  FAILED_EXTERNAL_ACTION,
+  LOGIN_FAILED,
+  SET_USERMSG_NOTIFIED,
+} from '../constants'
 import { actionReducer } from './utils'
 
 function addLogEntry ({ state, message, type = 'ERROR', failedAction }) {
   // TODO: use seq
   return state
     .set('unread', true)
-    .update('records', records => records.push({
+    .update('records', records => records.push(Immutable.fromJS({
       message,
       type,
       failedAction,
       time: Date.now(),
-    }))
+      notified: false,
+    })))
 }
 
 /**
@@ -28,7 +36,7 @@ const initialState = Immutable.fromJS({
 })
 
 const userMessages = actionReducer(initialState, {
-  FAILED_EXTERNAL_ACTION (state, { payload: { message, shortMessage, type, action } }) { // see the vms() reducer
+  [FAILED_EXTERNAL_ACTION] (state, { payload: { message, shortMessage, type, action } }) { // see the vms() reducer
     return addLogEntry({
       state,
       message: message,
@@ -37,12 +45,18 @@ const userMessages = actionReducer(initialState, {
       failedAction: action,
     })
   },
-  LOGIN_FAILED (state, { payload: { message, errorCode } }) {
+  [LOGIN_FAILED] (state, { payload: { message, errorCode } }) {
     return addLogEntry({ state, message: message, type: errorCode })
   },
-  CLEAR_USER_MSGS (state) {
+  [CLEAR_USER_MSGS] (state) {
     return state.set('unread', false).update('records', records => records.clear())
   },
+  [SET_USERMSG_NOTIFIED] (state, { payload: { time } }) {
+    return state.setIn(['records', state.get('records').findIndex(r => r.get('time') === time), 'notified'], true)
+  },
+  [DISMISS_USER_MSG] (state, { payload: { time } }) {
+    return state.update('records', records => records.delete(state.get('records').findIndex(r => r.get('time') === time)))
+  },
 })
 
 export default userMessages
